@@ -24,6 +24,8 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include <rhash.h>
+
 #include <igloo/typedef.h>
 
 typedef struct igloo_instance_tag igloo_instance_t;
@@ -65,6 +67,9 @@ igloo_error_t igloo_instance__new(igloo_ro_t self, const igloo_ro_type_t *type,
 
     (void)type, (void)ap;
 
+    /* bring up rhash early, it is used by the digest system and all that depends on it. */
+    rhash_library_init();
+
     instance->error = igloo_ERROR_NONE;
 
     error = igloo_instance_sp_init(&(instance->stringpool_state));
