@@ -532,7 +532,7 @@ static inline bool needs_to_be_kept_alive(igloo_ro_stub_t *stub)
         return needs_to_be_kept_alive_instance(stub);
     }
 
-    return stub->refc > 1;
+    return stub->refc > 0;
 }
 
 igloo_error_t   igloo_ro_unref_raw(igloo_ro_t *self)
@@ -973,17 +973,23 @@ igloo_error_t igloo_ro_bootstrap(igloo_ro_t *instance, const igloo_ro_type_t *ty
 
 igloo_ro_t igloo_ro_get_instance_unsafe(igloo_ro_t self, const igloo_ro_type_t *type)
 {
-    igloo_ro_t ret;
+    igloo_ro_stub_t *stub;
 
     if (!is_valid_object(self))
         return igloo_RO_NULL;
 
-    ret = igloo_RO_TO_TYPE_raw(self, type);
-    if (!igloo_ro_is_null(ret))
-        return ret;
+    stub = igloo_RO__GETSTUB(self);
 
-    if (!igloo_RO__GETSTUB(self)->group)
+    if (is_object_of_type(self, type)) {
+        if (stub->refc) {
+            return self;
+        } else {
+            return igloo_RO_NULL;
+        }
+    }
+
+    if (!stub->group)
         return igloo_RO_NULL;
 
-    return igloo_RO_TO_TYPE_raw(igloo_RO__GETSTUB(self)->group->instance, type);
+    return igloo_RO_TO_TYPE_raw(stub->group->instance, type);
 }
