@@ -1,4 +1,4 @@
-/* Copyright (C) 2020-2021  Philipp "ph3-der-loewe" Schafft <lion@lion.leolix.org>
+/* Copyright (C) 2020-2025  Philipp "ph3-der-loewe" Schafft <lion@lion.leolix.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -49,6 +49,8 @@ static const char *constant_strings[] = {
     "18446744073709551615", "18446744073709551616",
     "0x0", "0x00", "0xff", "0xFF",
     "00", "000",
+    "zero", "one", "two", "three", "four",
+    "hrair",
     // Truth values:
     "yes", "true", "ja", "wahr",
     "no", "false", "nein", "unwahr", "falsch",
@@ -95,6 +97,22 @@ static const char *constant_strings[] = {
     "6ba7b814-9dad-11d1-80b4-00c04fd430c8", // NameSpace_X500
     // stats:
     "stats", "listeners", "server_name", "listenurl", "clients", "connections",
+    // Universal Tags:
+    "uuid", "oid", "uri", "tagname", "wikidata-identifier", "musicbrainz-identifier",
+    "small-identifier", "sirtx-numerical-identifier", "chat-0-word-identifier",
+    "8be115d2-dc2f-4a98-91e1-a6e3075cbc31", // uuid
+    "d08dc905-bbf6-4183-b219-67723c3c8374", // oid
+    "a8d1637d-af19-49e9-9ef8-6bc1fbcf6439", // uri
+    "bfae7574-3dae-425d-89b1-9c087c140c23", // tagname
+    "ce7aae1e-a210-4214-926a-0ebca56d77e3", // wikidata-identifier
+    "95bd826b-bd3e-4b40-b16a-aa20c9f673e4", // musicbrainz-identifier
+    "f87a38cb-fd13-4e15-866c-e49901adbec5", // small-identifier
+    "039e0bb7-5dd3-40ee-a98c-596ff6cce405", // sirtx-numerical-identifier
+    "2c7e15ed-aa2f-4e2f-9a1d-64df0c85875a", // chat-0-word-identifier
+    // common paths and devices:
+    "/", "/dev", "/tmp", "/dev/null", "/dev/tty", "/dev/console", // POSIX
+    "/dev/stdin", "/dev/stdout", "/dev/stderr",
+    "/dev/random", "/dev/urandom",
     // Others:
     "Icecast", "icecast", "hackme", "test", "admin", "Earth", "igloo",
     "localhost", "127.0.0.1", "::1", "::",
@@ -110,7 +128,8 @@ static const char *constant_strings[] = {
     "filename", "hostname", "location",
     "port",
     "implementation", "version", "config", "configuration",
-    "/"
+    "icon", "thumbnail",
+    "EOF"
 };
 
 static pthread_once_t constant_strings_sort = PTHREAD_ONCE_INIT;
